
<table class="ptable" cellspacing=0 cellpadding=0><tr>
<td class=elem width=30>  <a href="{{url_for('element')}}H">H </a> </td>
<td colspan=16></td>
<td class=elem width=30>  <a href="{{url_for('element')}}He">He </a></td>
</tr><tr>
<td class=elem width=30>  <a href="{{url_for('element')}}Li">Li </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Be">Be </a></td>
<td colspan=10></td>
<td class=elem width=30>  <a href="{{url_for('element')}}B ">B </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}C">C </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}N">N </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}O">O </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}F">F </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ne">Ne </a></td>
</tr><tr>
<td class=elem width=30>  <a href="{{url_for('element')}}Na">Na </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Mg">Mg </a></td>
<td colspan=10></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Al">Al </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Si">Si </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}P">P </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}S">S </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Cl">Cl </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ar">Ar </a></td>
</tr><tr>
<td class=elem width=30>  <a href="{{url_for('element')}}K">K </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ca">Ca </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Sc">Sc </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ti">Ti </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}V" >V  </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Cr">Cr </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Mn">Mn </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Fe">Fe </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Co">Co </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ni">Ni </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Cu">Cu </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Zn">Zn </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ga">Ga </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ge">Ge </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}As">As </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Se">Se </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Br">Br </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Kr">Kr </a></td>
</tr><tr>
<td class=elem width=30>  <a href="{{url_for('element')}}Rb">Rb </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Sr">Sr </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Y">Y </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Zr">Zr </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Nb">Nb </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Mo">Mo </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Tc">Tc </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ru">Ru </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Rh">Rh </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Pd">Pd </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ag">Ag </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Cd">Cd </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}In">In </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Sn">Sn </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Sb">Sb </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Te">Te </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}I">I </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Xe">Xe </a></td>
</tr><tr>
<td class=elem width=30>  <a href="{{url_for('element')}}Cs">Cs </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ba">Ba </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}La">La </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Hf">Hf </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ta">Ta </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}W">W </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Re">Re </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Os">Os </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ir">Ir </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Pt">Pt </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Au">Au </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Hg">Hg </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Tl">Tl </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Pb">Pb </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Bi">Bi </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Po">Po </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}At">At </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Rn">Rn </a></td>
</tr><tr>
<td class=elem width=30>  <a href="{{url_for('element')}}Fr">Fr </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ra">Ra </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ac">Ac </a></td>
</tr><tr>
<td colspan=3></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ce">Ce </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Pr">Pr </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Nd">Nd </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Pm">Pm </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Sm">Sm </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Eu">Eu </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Gd">Gd </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Tb">Tb </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Dy">Dy </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Ho">Ho </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Er">Er </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Tm">Tm </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Yb">Yb </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Lu">Lu </a></td>
</tr><tr>
<td colspan=3></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Th">Th </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Pa">Pa </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}U">U </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Np">Np </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Pu">Pu </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Am">Am </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Cm">Cm </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Bk">Bk </a></td>
<td class=elem width=30>  <a href="{{url_for('element')}}Cf">Cf </a></td>
</tr><tr>
</table>
