a, h1, h2  {color: #16C; text-decoration: none; }
h1, h2     {font-family: 'Georgia', serif; margin: 0; }
h1         {border-bottom: 1px solid #eee; }
h2         {font-size: 1.2em; }

.body  { font-family: sans-serif; margin:5px; padding:2px;
         background-color: #FFF; font: 12px verdana, sans-serif;}

.body a, a.active {color: #16C; text-decoration: none; }
.body a.active    {color: #C61;  background-color: #FDFDFA;}
.body a:hover     {color: #C61;  background-color: #F0F0F6;}

.colSpacing {padding:0 5px;}

table td, table td * {     vertical-align: top; }

.flex-container {display: flex; flex-direction: row; margin: 2px;}
.flex-child {flex: 1;}
.flex-child:first-child {margin-right: 20px;}

.even {background-color: #F3F3F0;}
.odd {background-color: #FFFFFF;}


.entries        { list-style: none; margin: 0; padding: 0; }
.entries li     { margin: 0.2em 30em; }
.entries li h2  { margin-left: -1em; }
.add-entry      { font-size: 0.9em; border-bottom: 0px solid #ccc; }

.warning  { background-color: #cee5F5; padding: 0.5em; border: 3px solid #aacbe2; }
.error    { background-color: #F0F0F6; padding: 0.5em; border: 3px solid #702020; }


.subfont {font:bold 16px verdana, arial, sans-serif;color:#CC0000;}
.subtitle {font:bold 16px verdana, arial, sans-serif;color:#CC0000;}

.confirm {font-family: sans-serif; margin:5px; padding:2px;
          background-color: #FFFFFF; font:bold 14px verdana,sans-serif;}
.confirm a, a.active {color: #444AAA;  font:bold 14px verdana,sans-serif;}

pre {text-indent: 16px}
h5 {font:bold 12px verdana,arial,sans-serif;color:#042264;}
h4 {font:bold 14px verdana,arial,sans-serif;color:#042264;}
h3 {font:bold 16px verdana,arial,sans-serif;color:#A42424; font-weight:bold;font-style:italic;}

h2 {font:bold 18px verdana,arial,sans-serif;color:#044484;font-weight:bold;}

.ptable {background-color:#FDFDFD;}

.elem {font: bold 16px verdana; color: #333; background-color:#FDFDFD;
       text-align:justify; padding: 2px;}
.elem a, a.active {color: #16C; text-decoration: none; }
.elem a.active {color: #C61;  background-color: #FDFDFD;}
.elem a:hover  {color: #C61;  background-color: #F0F0F6;}

.topbar {font: bold 16px verdana, arial, sans-serif;
         padding: 2px 4px 4px 4px;text-decoration: none;
         color: #FFF;   background-color: #16C;}

.topbar a        {background-color: #16C; color: #FEA; margin: 5px 5px 5px 5px;}
.topbar a:hover  {background-color: #27D; color: #FAF0C0;
                  transition: 0.5s ease-in;
                  margin: 5px 5px 5px 5px;}

.topmenu { font: bold 13px verdana, arial, sans-serif; margin: 0px;
           padding: 0px 0px 16px 0px;   border: 3px solid #16C;
           background-color: #FDFDFD;}

.topmenu ul {margin: 0px;  padding: 0px}
.topmenu li {float: left;  display: inline;
             margin: 0px;
             list-style-type: none;
             border-right: 3px solid #2090B0;
             padding: 0px 10px 0px 10px;
             color: #FEA;   background-color: #F6F6F9;}

.topmenu a, a.active {color: #16C; }
.topmenu a.active    {color: #16C; background-color: #FE9;}
.topmenu a:hover     {color: #16C; background-color: #FE9; transition: 0.5s ease-in; }
.topmenu li:hover    {color: #16C; background-color: #FE9; transition: 1.0s ease-in; }

.abutton {
    font: 12px verdana, sans-serif;
    text-decoration: none;
    color: #004;
    background-color: #F3F3F0;
    padding: 2px 5px 2px 5px;
    border-left:   0.8px solid #777;
    border-bottom: 0.8px solid #777;
    border-top:    0.5px solid #BBB;
    border-right:  0.5px solid #BBB;
    border-radius: 2px;
}

.abutton:hover {background-color: #FEA; transition: 1s ease-in; }


.fileinput {
    size: 6000px;
    font: 12px verdana, sans-serif;
    content: 'Choose File';
    display: inline-block;
    background-color: #F3F3F0;
    padding: 2px 5px 2px 5px;
    border-left:   0.8px solid #777;
    border-bottom: 0.8px solid #777;
    border-top:    0.5px solid #BBB;
    border-right:  0.5px solid #BBB;
    border-radius: 2px;
}

.fileinput:hover {background: #FEA; transition: 1s ease-in;}

.fileinput:active {    background: #FEA; }
