{% extends "layout.html" %}

{% block body %}
<div class=body>
    {% if error %}
    <p>{{error}}</p>
    {% endif %}
    
    Xrayweb was written by Alex Nicolellis and Matthew Newville at
    <a href=https://gsecars.uchicago.edu>GSECARS</a> at the University
    of Chicago.
    <p>
      
      For details on the X-ray data sources and calculations done here,
      consult the <a href=https://xraypy.github.io/XrayDB/>XrayDB Python
      library</a>, which is used for all the calculation here. 

   <p>
  
     Code for the web pages for xrayweb is at
     <a href=https://github.com/xraypy/xrayweb>xrayweb at github.com</a>,

     Xrayweb is written in Python, using the libraries Numpy, Flask, and
     using the javascript plotting library Plotly.
     
   <p>
</div>
{% endblock %}
