<table class="mtable" cellspacing=10 cellpadding=0>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}water">Water </a></td>
    <td class=material>  <a href="{{url_for('formula')}}lead">Lead </a></td>
    <td class=material>  <a href="{{url_for('formula')}}aluminum">Aluminum </a></td>
    <td class=material>  <a href="{{url_for('formula')}}kapton">Kapton </a></td>
    <td class=material>  <a href="{{url_for('formula')}}polyimide">Polyimide </a></td>
    <td class=material>  <a href="{{url_for('formula')}}nitrogen">Nitrogen </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}argon">Argon </a></td>
    <td class=material>  <a href="{{url_for('formula')}}helium">Helium </a></td>
    <td class=material>  <a href="{{url_for('formula')}}neon">Neon </a></td>
    <td class=material>  <a href="{{url_for('formula')}}krypton">Krypton </a></td>
    <td class=material>  <a href="{{url_for('formula')}}xenon">Xenon </a></td>
    <td class=material>  <a href="{{url_for('formula')}}air">Air </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}diamond">Diamond </a></td>
    <td class=material>  <a href="{{url_for('formula')}}graphite">Graphite </a></td>
    <td class=material>  <a href="{{url_for('formula')}}carbon">Carbon </a></td>
    <td class=material>  <a href="{{url_for('formula')}}boron nitride">Boron Nitride </a></td>
    <td class=material>  <a href="{{url_for('formula')}}cubic boron nitride">Cubic Boron Nitride </a></td>
    <td class=material>  <a href="{{url_for('formula')}}silicon nitride">Silicon Nitride </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}yag">Yag </a></td>
    <td class=material>  <a href="{{url_for('formula')}}sapphire">Sapphire </a></td>
    <td class=material>  <a href="{{url_for('formula')}}polypropylene">Polypropylene </a></td>
    <td class=material>  <a href="{{url_for('formula')}}pmma">Pmma </a></td>
    <td class=material>  <a href="{{url_for('formula')}}polycarbonate">Polycarbonate </a></td>
    <td class=material>  <a href="{{url_for('formula')}}kimol">Kimol </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}mylar">Mylar </a></td>
    <td class=material>  <a href="{{url_for('formula')}}teflon">Teflon </a></td>
    <td class=material>  <a href="{{url_for('formula')}}parylene-c">Parylene-c </a></td>
    <td class=material>  <a href="{{url_for('formula')}}parylene-n">Parylene-n </a></td>
    <td class=material>  <a href="{{url_for('formula')}}fluorite">Fluorite </a></td>
    <td class=material>  <a href="{{url_for('formula')}}mica">Mica </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}salt">Salt </a></td>
    <td class=material>  <a href="{{url_for('formula')}}silica">Silica </a></td>
    <td class=material>  <a href="{{url_for('formula')}}quartz">Quartz </a></td>
    <td class=material>  <a href="{{url_for('formula')}}rutile">Rutile </a></td>
    <td class=material>  <a href="{{url_for('formula')}}ule">Ule </a></td>
    <td class=material>  <a href="{{url_for('formula')}}zerodur">Zerodur </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}copper">Copper </a></td>
    <td class=material>  <a href="{{url_for('formula')}}molybdenum">Molybdenum </a></td>
    <td class=material>  <a href="{{url_for('formula')}}iron">Iron </a></td>
    <td class=material>  <a href="{{url_for('formula')}}zinc">Zinc </a></td>
    <td class=material>  <a href="{{url_for('formula')}}silicon">Silicon </a></td>
    <td class=material>  <a href="{{url_for('formula')}}germanium">Germanium </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}gold">Gold </a></td>
    <td class=material>  <a href="{{url_for('formula')}}silver">Silver </a></td>
    <td class=material>  <a href="{{url_for('formula')}}platinum">Platinum </a></td>

    <td class=material>  <a href="{{url_for('formula')}}tungsten">Tungsten </a></td>
    <td class=material>  <a href="{{url_for('formula')}}acetone">Acetone </a></td>
    <td class=material>  <a href="{{url_for('formula')}}methanol">Methanol </a></td>
    <tr></tr>
    <td class=material>  <a href="{{url_for('formula')}}isopropanol">Isopropanol </a></td>
    <td class=material>  <a href="{{url_for('formula')}}toluene">Toluene </a></td>
    <td class=material>  <a href="{{url_for('formula')}}xylene">Xylene </a></td>
</table>